## Change log

### 0.1.1
+   Incease minimum topup_account funds to 10,000,000
+   Allow to register and load accounts using a name

### 0.1.0
+   Now need to use ConvexAPI.create_account method to create a new account, and get the address number
+   Internal bug fixes, and name conventions for the API calls

### 0.0.8
+   Rebuild with new release

### 0.0.7
+   Rename Account create_new to create
+   Rename Account create_from_bytes to import_from_bytes

### 0.0.6
+   Add topup_account method to api

### 0.0.5
+   Add a 0x prefix to retuned addresses

### 0.0.4
+   Import/export account private keys as a word phrase
+   Convex Wallet tool

### 0.0.3
+   Pre-alpha release

### 0.0.2
+   Add retry sending a transcation during a SEQUENCE error

### 0.0.1
+   Initial Alpha Release
